lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite for Android: free password hash cracker in your pocket
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:   Fri, 27 Oct 2023 14:21:52 +0530
From:   Pavan Bobba <opensource206@...il.com>
To:     Greg Kroah-Hartman <gregkh@...uxfoundation.org>,
        linux-staging@...ts.linux.dev, linux-kernel@...r.kernel.org
Cc:     Pavan Bobba <opensource206@...il.com>
Subject: [PATCH 03/10] staging: vt6655: Type encoding info dropped from variable name "pbyTxRate"

variable name "pbyTxRate" updated like below:

a.type encoding info dropped from name
b.camelcase name replaced by snakecase

Issue found by checkpatch

Signed-off-by: Pavan Bobba <opensource206@...il.com>
---
 drivers/staging/vt6655/card.c | 36 +++++++++++++++++------------------
 1 file changed, 18 insertions(+), 18 deletions(-)

diff --git a/drivers/staging/vt6655/card.c b/drivers/staging/vt6655/card.c
index 2968be1f8d4e..4ee9b48de2c2 100644
--- a/drivers/staging/vt6655/card.c
+++ b/drivers/staging/vt6655/card.c
@@ -75,83 +75,83 @@ static void vt6655_mac_set_bb_type(void __iomem *iobase, u32 mask)
  *      wRate           - Tx Rate
  *      byPktType       - Tx Packet type
  *  Out:
  *      pbyTxRate       - pointer to RSPINF TxRate field
  *      pbyRsvTime      - pointer to RSPINF RsvTime field
  *
  * Return Value: none
  */
 static void calculate_ofdmr_parameter(unsigned char rate,
 				       u8 bb_type,
-				       unsigned char *pbyTxRate,
+				       unsigned char *tx_rate,
 				       unsigned char *pbyRsvTime)
 {
 	switch (rate) {
 	case RATE_6M:
 		if (bb_type == BB_TYPE_11A) { /* 5GHZ */
-			*pbyTxRate = 0x9B;
+			*tx_rate = 0x9B;
 			*pbyRsvTime = 44;
 		} else {
-			*pbyTxRate = 0x8B;
+			*tx_rate = 0x8B;
 			*pbyRsvTime = 50;
 		}
 		break;
 
 	case RATE_9M:
 		if (bb_type == BB_TYPE_11A) { /* 5GHZ */
-			*pbyTxRate = 0x9F;
+			*tx_rate = 0x9F;
 			*pbyRsvTime = 36;
 		} else {
-			*pbyTxRate = 0x8F;
+			*tx_rate = 0x8F;
 			*pbyRsvTime = 42;
 		}
 		break;
 
 	case RATE_12M:
 		if (bb_type == BB_TYPE_11A) { /* 5GHZ */
-			*pbyTxRate = 0x9A;
+			*tx_rate = 0x9A;
 			*pbyRsvTime = 32;
 		} else {
-			*pbyTxRate = 0x8A;
+			*tx_rate = 0x8A;
 			*pbyRsvTime = 38;
 		}
 		break;
 
 	case RATE_18M:
 		if (bb_type == BB_TYPE_11A) { /* 5GHZ */
-			*pbyTxRate = 0x9E;
+			*tx_rate = 0x9E;
 			*pbyRsvTime = 28;
 		} else {
-			*pbyTxRate = 0x8E;
+			*tx_rate = 0x8E;
 			*pbyRsvTime = 34;
 		}
 		break;
 
 	case RATE_36M:
 		if (bb_type == BB_TYPE_11A) { /* 5GHZ */
-			*pbyTxRate = 0x9D;
+			*tx_rate = 0x9D;
 			*pbyRsvTime = 24;
 		} else {
-			*pbyTxRate = 0x8D;
+			*tx_rate = 0x8D;
 			*pbyRsvTime = 30;
 		}
 		break;
 
 	case RATE_48M:
 		if (bb_type == BB_TYPE_11A) { /* 5GHZ */
-			*pbyTxRate = 0x98;
+			*tx_rate = 0x98;
 			*pbyRsvTime = 24;
 		} else {
-			*pbyTxRate = 0x88;
+			*tx_rate = 0x88;
 			*pbyRsvTime = 30;
 		}
 		break;
 
 	case RATE_54M:
 		if (bb_type == BB_TYPE_11A) { /* 5GHZ */
-			*pbyTxRate = 0x9C;
+			*tx_rate = 0x9C;
 			*pbyRsvTime = 24;
 		} else {
-			*pbyTxRate = 0x8C;
+			*tx_rate = 0x8C;
 			*pbyRsvTime = 30;
 		}
 		break;
@@ -159,10 +159,10 @@ static void calculate_ofdmr_parameter(unsigned char rate,
 	case RATE_24M:
 	default:
 		if (bb_type == BB_TYPE_11A) { /* 5GHZ */
-			*pbyTxRate = 0x99;
+			*tx_rate = 0x99;
 			*pbyRsvTime = 28;
 		} else {
-			*pbyTxRate = 0x89;
+			*tx_rate = 0x89;
 			*pbyRsvTime = 34;
 		}
 		break;
@@ -75,83 +75,83 @@ static void vt6655_mac_set_bb_type(void __iomem *iobase, u32 mask)
  *      byPktType       - Tx Packet type
  *  Out:
- *      pbyTxRate       - pointer to RSPINF TxRate field
+ *      tx_rate         - pointer to RSPINF TxRate field
  *      pbyRsvTime      - pointer to RSPINF RsvTime field
  *
-- 
2.34.1

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ